USCFC Vaccine-Unreported | US Court of Federal Claims

Skip to main content
Site map

# USCFC Vaccine-Unreported

U.S. Court of Federal Claims Opinions
Updated: 6 hours 34 min ago

General Jurisdiction (Reported) | General Jurisdiction (Unreported) | Vaccine (Reported) | Vaccine (Unreported) | Search for:

### 1:13-vv-00514 • GRAHAM v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/07/2014
PUBLIC DECISION (Originally filed: 04/02/2014) regarding DECISION Stipulation/Proffer Signed by Special Master Laura D Millman.

Keywords: re: Public Decision: Attorneys' fees and costs decision based on stipulation of fact

### 1:13-vv-00514 • GRAHAM v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/07/2014
PUBLIC DECISION (Originally filed: 04/16/2014) regarding DECISION Fees Stipulation/Proffer Signed by Special Master Laura D Millman.

Keywords: re: Public Decision: Attorneys' fees and costs decision based on stipulation of fact

### 1:14-vv-00212 • HARRINGTON v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/07/2014
PUBLIC ORDER/RULING (Originally filed: 04/16/2014) regarding Order Concluding Proceedings Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Order Concluding Proceedings; More Than One Petition for Same Vaccine Administration

### 1:11-vv-00553 • RIVERA v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/06/2014
PUBLIC DECISION (Originally filed: 4/15/12014) regarding DECISION Stipulation/Proffer, DECISION Fees Stipulation/Proffer (Signed by Special Master Thomas L. Gowen.)

Keywords: Stipulation; GBS; Flu

### 1:12-vv-00884 • KOETJE v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/06/2014
PUBLIC DECISION (Originally filed: 04/15/2014) regarding DECISION Stipulation/Proffer Signed by Special Master Laura D Millman.

Keywords: re: Public Decision: Damages decision based on stipulation; DTaP vaccine; acute demyelinating encephalomyelitis

### 1:03-vv-02765 • CARROLL et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/06/2014
PUBLIC DECISION (Originally filed: 04/10/14) regarding DECISION Fees Stipulation/Proffer Signed by Special Master George L. Hastings.

Keywords: re: Public Decision. Decision on Attorney's Fees and Costs

### 1:13-vv-00554 • CORUM v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/06/2014
PUBLIC DECISION (Originally filed: 04/14/2014) regarding DECISION Stipulation/Proffer Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Influenza vaccine; Transverse Myelitis; Decision; Stipulation. (dlb)Keywords: re: Decision on Attorneys' Fees and Costs.

### 1:03-vv-02765 • CARROLL et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/06/2014
PUBLIC DECISION Signed by Special Master George L. Hastings.

Keywords: re: Public Decision. Decision on Attorney's Fees and Costs

### 1:13-vv-00554 • CORUM v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/06/2014
PUBLIC DECISION (Originally filed: 04/14/2014) regarding DECISION Fees Stipulation/Proffer Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Influenza vaccine; Transverse Myelitis; Decision; Stipulation. (dlb)Keywords: re: Decision on Attorneys' Fees and Costs.

### 1:11-vv-00627 • WALLACE v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/06/2014
PUBLIC DECISION Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Decision on Attorneys' Fees and Costs.

### 1:11-vv-00627 • WALLACE v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/06/2014
PUBLIC DECISION (Originally filed: 04/14/2014) regarding DECISION Fees Stipulation/Proffer Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Decision on Attorneys' Fees and Costs.

### 1:13-vv-00818 • SULLIVAN BARKER v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/02/2014
PUBLIC DECISION (Originally filed: 04/11/2014) regarding DECISION of Special Master Signed by Special Master Laura D Millman.

Keywords: re: DECISION of Special Master: FluMist; GBS; no credible proof of GBS; no proof of neurologic injury

### 1:12-vv-00348 • COMEAUX et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/01/2014
PUBLIC DECISION (Originally filed: 04/10/2014) regarding DECISION Fees Stipulation/Proffer. Signed by Special Master Christian J. Moran.

Keywords: re: Public Decision Attorneys' fees and costs; award in the amount to which respondent does not object

### 1:09-vv-00674 • REESE v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/01/2014
PUBLIC DECISION (Originally filed: 04/10/2014) regarding DECISION Fees Stipulation/Proffer. Signed by Chief Special Master Denise Kathryn Vowell.

Keywords: re: Public Decision Autism; Stipulation; Attorneys' Fees and Costs

### 1:13-vv-00199 • GOESCHEL v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/01/2014
PUBLIC DECISION (Originally filed: 04/09/2014) regarding DECISION Stipulation/Proffer. Signed by Special Master Christian J. Moran.

Keywords: re: Public Decision Stipulation; influenza ("flu") vaccine; Guillain-Barre Syndrome ("GBS")

### 1:12-vv-00644 • WEALAND v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/01/2014
PUBLIC DECISION (Originally filed: 04/10/2014) regarding DECISION Stipulation/Proffer. Signed by Special Master Christian J. Moran.

Keywords: re: Public Decision Stipulation; Influenza ("flu") Vaccine; Guillain-Barre Syndrome ("GBS")

### 1:12-vv-00407 • MIRELES v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/01/2014
PUBLIC DECISION (Originally filed: 04/09/2014) regarding DECISION Stipulation/Proffer. Signed by Special Master Christian J. Moran.

Keywords: re: Public Decision Stipulation; Influenza Vaccine ("flu"); Guillain-Barre syndrome ("GBS")

### 1:12-vv-00461 • MONTELEONE v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/01/2014
PUBLIC DECISION (Originally filed: 04/08/2014) regarding DECISION Stipulation/Proffer. Signed by Special Master Christian J. Moran.

Keywords: re: Public Decision Stipulation; Influenza Vaccine ("flu"); Guillain-Barre syndrome ("GBS")

### 1:13-vv-00140 • ROYAL v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/01/2014
PUBLIC DECISION (Originally filed: 04/10/2014) regarding DECISION Stipulation/Proffer Signed by Special Master Laura D Millman.

Keywords: re: Public Decision: Damages decision based on stipulation; influenza vaccine; lichenoid drug eruption

### 1:97-vv-00588 • LUMSDEN v. HHS

Filed 05/01/2014
PUBLIC DECISION (Originally filed: 4/7/2014) regarding DECISION Fees Stipulation/Proffer. Signed by Chief Special Master Denise Kathryn Vowell.

Keywords: re: Public Decision Stipulation; Attorney Fees and Costs

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »